@@ -10,11 +10,8 @@ sub write_out {
     my $feed = shift;
     my $json;
     
-    my @config_search_path = ( $feed->{'query'}, 'client' );
-
-	# fyi
-	#   my $cfg_csv_noseparator = confor($config, \@config_search_path, 'csv_noseparator', undef);
-        
+    my @config_search_path = ('claoverride',  $feed->{'query'}, 'client' );
+    
     if(1 || $config->{'stream'}){
         my @array = @{$feed->{'feed'}->{'entry'}};
         return unless(keys(%{$array[0]}));
@@ -22,11 +19,12 @@ sub write_out {
         foreach(@array){
             push(@json_stream,JSON::to_json($_));
         }
-        $json = join("\n",@json_stream);
+        $json = join(',',@json_stream);
+        $json = '['.$json.']';
     } else {
         return unless($feed->{'feed'}->{'entry'});
         $json = JSON::to_json($feed->{'feed'}->{'entry'});
     }
-    return $json."\n";
+    return $json;
 }
 1;
